package org.campbelli.ejb;

import org.campbelli.ejb.bean.UserToken;
import org.jboss.security.auth.callback.AppCallbackHandler;
import org.jboss.security.client.SecurityClient;
import org.jboss.security.client.SecurityClientFactory;
import org.testng.Assert;
import org.testng.annotations.*;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.security.auth.callback.CallbackHandler;

public class MainSessionBeanTest {

    private MainSessionRemote remote = null;

    SecurityClient client = null;

    static {
        System.setProperty("java.security.auth.login.config","/home/vit/projects/jaas/src/test/resources/auth.conf");
    }

    @BeforeClass
    public void setUp() throws Exception {
        Context ctx = new InitialContext();
        remote = (MainSessionRemote) ctx.lookup("MainSessionEJB/remote");
        String token = remote.getToken(getToken());

        CallbackHandler handler = new AppCallbackHandler(token, "pass123".toCharArray());
        client = SecurityClientFactory.getSecurityClient();
        client.setJAAS("myPolicy", handler);
        client.login();
    }

    @AfterClass
    public void tearDown() throws Exception {
        client.logout();
    }

    private UserToken getToken()  {
        UserToken userToken = new UserToken();
        userToken.setId(1L);
        userToken.setUsername("user_test");
        userToken.setRole("admin");
       return userToken;
    }

    @Test
    public void testTest() throws Exception {
        String response = remote.test("Vit");
        Assert.assertEquals("Test Vit", response);
    }

    @Test
    public void testTestHi() throws Exception {
        String response = remote.testHi("Vit");
        Assert.assertEquals("Hi Vit", response);
    }

    @Test
    public void testTestBye() throws Exception {
        String response = remote.testBye("Vit");
        Assert.assertEquals("Bye Vit", response);
    }
}
